@@ -9,18 +9,15 @@ if hasattr(settings, "PAGADOR_CONF_PATH") and settings.PAGADOR_CONF_PATH is not
     config_path = settings.PAGADOR_CONF_PATH
 
 config = Config.load(config_path)
-
 MEDIA_URL = config.MEDIA_URL
-
 DEBUG = config.DEBUG
-
+CHAVE_APLICACAO = config.CHAVE_APLICACAO
 LIBS_MEIOS_DE_PAGAMENTO = config.LIBS_MEIOS_DE_PAGAMENTO
-
 QUEUE_URL = config.QUEUE_URL
 GRAVA_EVIDENCIA = config.GRAVA_EVIDENCIA
 EVIDENCIA_URL = config.EVIDENCIA_URL
-
+EVIDENCIA_USA_AUTENTICACAO_HEADER = config.EVIDENCIA_USA_AUTENTICACAO_HEADER
+EVIDENCIA_HEADER_AUTENTICACAO = config.EVIDENCIA_HEADER_AUTENTICACAO
 MODULO_PARAMETROS_INSTALACAO = config.MODULO_PARAMETROS_INSTALACAO
-
 MERCADOPAGO_REDIRECT_URL = config.MERCADOPAGO_REDIRECT_URL
 MERCADOPAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADOPAGO_PREFERENCE_NOTIFICATION_URL
\ No newline at end of file
